<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Analog clock settings</source>
        <translation>Nastavení ručičkových hodin</translation>
    </message>
    <message>
        <source>Show &amp;seconds hand</source>
        <translation>Ukázat ručičku pro &amp;sekundy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Clock</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Clock:</source>
        <translation>Hodiny:</translation>
    </message>
</context>
</TS>